@@ -1,5 +1,9 @@
 <?php
-$lang['error_insufficientparams'] = 'Param&egrave;tres insuffisant';
+$lang['error_feu_loggedin'] = 'cet utilisateur n&#039;est pas connect&eacute; &agrave; FEU. Ajouter ou modifier les &eacute;v&eacute;nements n&#039;est pas permis.';
+$lang['prompt_friendlyname'] = 'Nom &quot;convivial&quot; pour ce module dans la navigation de l&#039;administration';
+$lang['info_friendlyname'] = 'Note : Il se peut que vous ayez &agrave; vider le cache du site pour que cette pr&eacute;f&eacute;rence prenne effet. Si aucune valeur n&#039;est fournie, une valeur par d&eacute;faut sera utilis&eacute;e.';
+$lang['use_wysiwyg'] = 'Utilise le Wysiwyg';
+$lang['error_insufficientparams'] = 'Param&egrave;tres insuffisants';
 $lang['column_delimiter'] = 'Import file column delimiter';
 $lang['import_completed'] = 'Importation termin&eacute;';
 $lang['num_imported'] = 'Nombre d&#039;&eacute;v&egrave;nements cr&eacute;&eacute;s: %d';
@@ -426,4 +430,6 @@ $lang['cal_recur_until'] = 'R&eacute;p&egrave;te jusqu&#039;&agrave;';
 $lang['help_template'] = '<p><b>Affiche le nom de l&#039;auteur :</b></p>
 <code>Auteur : {$event.authorname}</code>
 ';
-?>
+$lang['utma'] = '156861353.3775108633884901000.1235391363.1296071805.1296172731.93';
+$lang['qca'] = 'P0-186310954-1257243985177';
+?>
\ No newline at end of file
